Downsample activity index data to fixed intervals
Value
Downsampled data frame with activity index summarized by total distance per bin and a .flicker_corrected logical flag indicating whether flicker correction was applied in each bin. Missing data for time bins will be filled with NA.